@@ -20,7 +20,7 @@ def list_cmd(args):
     "List notes files based on query arguments"
     reporoot = args.reporoot.rstrip('/') + '/'
     notesdir = utils.get_notes_dir(args)
-    notes = scanner.get_notes_by_version(reporoot, notesdir)
+    notes = scanner.get_notes_by_version(reporoot, notesdir, args.branch)
     if args.version:
         versions = args.version
     else:
@@ -28,8 +28,8 @@ def list_cmd(args):
     for version in versions:
         notefiles = notes[version]
         print(version)
-        for n in notefiles:
+        for n, sha in notefiles:
             if n.startswith(reporoot):
                 n = n[len(reporoot):]
-            print('\t%s' % n)
+            print('\t%s (%s)' % (n, sha))
     return
