@@ -14,6 +14,7 @@ import argparse
 import sys
 
 from reno import create
+from reno import defaults
 from reno import lister
 from reno import report
 
@@ -23,7 +24,7 @@ def main(argv=sys.argv[1:]):
     parser.add_argument(
         '--rel-notes-dir', '-d',
         dest='relnotesdir',
-        default='releasenotes',
+        default=defaults.RELEASE_NOTES_SUBDIR,
         help='location of release notes YAML files',
     )
     subparsers = parser.add_subparsers(
@@ -54,6 +55,11 @@ def main(argv=sys.argv[1:]):
         action='append',
         help='the version(s) to include, defaults to all',
     )
+    do_list.add_argument(
+        '--branch',
+        default=None,
+        help='the branch to scan, defaults to the current',
+    )
     do_list.set_defaults(func=lister.list_cmd)
 
     do_report = subparsers.add_parser(
@@ -69,6 +75,11 @@ def main(argv=sys.argv[1:]):
         default=None,
         help='output filename, defaults to stdout',
     )
+    do_report.add_argument(
+        '--branch',
+        default=None,
+        help='the branch to scan, defaults to the current',
+    )
     do_report.add_argument(
         '--version',
         default=[],
